.. libEnsemble documentation master file, created by
   sphinx-quickstart on Fri Aug 18 11:52:31 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: welcome.rst

.. toctree::
   :maxdepth: 2
   :caption: User Guide:

   Quickstart<introduction>
   advanced_installation
   overview_usecases
   programming_libE
   running_libE
   platforms/platforms_index

.. toctree::
   :maxdepth: 2
   :caption: Tutorials:

   tutorials/local_sine_tutorial
   tutorials/executor_forces_tutorial
   tutorials/aposmm_tutorial
   tutorials/calib_cancel_tutorial
   examples/examples_index

.. toctree::
   :maxdepth: 2
   :caption: Additional References:

   FAQ
   known_issues
   release_notes
   contributing
   posters

.. toctree::
   :maxdepth: 2
   :caption: Developer Guide:

   dev_guide/release_management/release_index
   dev_guide/dev_API/developer_API

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
